@@ -447,153 +447,4 @@ sub quit_search_dialog {
 	$win->Destroy();
 }
 #######################
-1;
-
-__END__
-
-
-sub foreward_keyfilter {
-	my ( $win, $event ) = ( shift->GetParent, shift );
-	my $key_code = $event->GetKeyCode;
-
-	if ( $key_code == WXK_TAB ) {
-		$event->ShiftDown
-		? Wx::Window::SetFocus($win->{close_button})
-		: Wx::Window::SetFocus($win->{range_group});
-	}
-	if ($key_code == WXK_RETURN or $key_code == WXK_SPACE) {
-		Kephra::Edit::Search::find_next()
-	}
-	if ( $key_code == WXK_ESCAPE ) { $win->Close }
-	if ( $key_code == 316 ) { Wx::Window::SetFocus( $win->{close_button} ) }
-	if ( $key_code == 317 ) { Wx::Window::SetFocus( $win->{close_button} ) }
-	if ( $key_code == 318 ) { Wx::Window::SetFocus( $win->{close_button} ) }
-	if ( $key_code == 319 ) { Wx::Window::SetFocus( $win->{close_button} ) }
-	$event->Skip;
-}
-
-sub backward_keyfilter {
-	my ( $win, $event ) = ( shift->GetParent, shift );
-	my $key_code = $event->GetKeyCode;
-
-	if ( $key_code == WXK_TAB ) {
-		$event->ShiftDown
-		? Wx::Window::SetFocus($win->{close_button})
-		: Wx::Window::SetFocus($win->{range_group});
-	}
-	if ($key_code == WXK_RETURN or $key_code == WXK_SPACE) {
-		Kephra::Edit::Search::find_prev()
-	}
-	if ( $key_code ==  WXK_ESCAPE ) { $win->Close }
-	if ( $key_code == 316 ) { Wx::Window::SetFocus( $win->{foreward_button} ) }
-	if ( $key_code == 317 ) { Wx::Window::SetFocus( $win->{replace_back} ) }
-	if ( $key_code == 318 ) { Wx::Window::SetFocus( $win->{replace_button} ) }
-	if ( $key_code == 319 ) { Wx::Window::SetFocus( $win->{fast_back_button} ) }
-}
-
-sub fast_fore_keyfilter {
-	my ( $win, $event ) = ( shift->GetParent, shift );
-	my $key_code = $event->GetKeyCode;
-
-	if ( $key_code == WXK_TAB ) {
-		$event->ShiftDown
-		? Wx::Window::SetFocus($win->{close_button})
-		: Wx::Window::SetFocus($win->{range_group});
-	}
-	if ($key_code == WXK_RETURN or $key_code == WXK_SPACE) {
-		Kephra::Edit::Search::fast_fore()
-	}
-	if ( $key_code == WXK_ESCAPE )  { $win->Close }
-	if ( $key_code == 316 ) { Wx::Window::SetFocus( $win->{range_group} ) }
-	if ( $key_code == 317 ) { Wx::Window::SetFocus( $win->{foreward_button} ) }
-	if ( $key_code == 318 ) { Wx::Window::SetFocus( $win->{fast_back_button} ) }
-	if ( $key_code == 319 ) { Wx::Window::SetFocus( $win->{first_button} ) }
-}
-
-sub fast_back_keyfilter {
-	my ( $win, $event ) = ( shift->GetParent, shift );
-	my $key_code = $event->GetKeyCode();
-	if ( $key_code == WXK_TAB ) {
-		$event->ShiftDown
-		? Wx::Window::SetFocus($win->{close_button})
-		: Wx::Window::SetFocus($win->{range_group});
-	}
-	if ($key_code == WXK_RETURN or $key_code == WXK_SPACE) {
-		Kephra::Edit::Search::fast_back( $win->GetParent() );
-	}
-	if ( $key_code == WXK_ESCAPE ) { $win->Close }
-	if ( $key_code == 316 ) { Wx::Window::SetFocus( $win->{fast_fore_button} ) }
-	if ( $key_code == 317 ) { Wx::Window::SetFocus( $win->{backward_button} ) }
-	if ( $key_code == 318 ) { Wx::Window::SetFocus( $win->{close_button} ) }
-	if ( $key_code == 319 ) { Wx::Window::SetFocus( $win->{last_button} ) }
-}
-
-sub first_keyfilter {
-	my ( $win, $event ) = ( shift->GetParent, shift );
-	my $key_code = $event->GetKeyCode;
-
-	if ( $key_code == WXK_TAB ) {
-		$event->ShiftDown
-		? Wx::Window::SetFocus($win->{close_button})
-		: Wx::Window::SetFocus($win->{range_group});
-	}
-	Kephra::Edit::Search::find_first() if $key_code == WXK_RETURN or $key_code == WXK_SPACE;
-	if ( $key_code ==  WXK_ESCAPE ) { $win->Close }
-	if ( $key_code == 316 ) { Wx::Window::SetFocus( $win->{range_group} ) }
-	if ( $key_code == 317 ) { Wx::Window::SetFocus( $win->{fast_fore_button} ) }
-	if ( $key_code == 318 ) { Wx::Window::SetFocus( $win->{last_button} ) }
-	if ( $key_code == 319 ) { Wx::Window::SetFocus( $win->{close_button} ) }
-}
-
-sub last_keyfilter {
-	my ($win, $event) = (shift->GetParent, shift);
-	my $key_code = $event->GetKeyCode;
-
-	Kephra::Edit::Search::find_last() if $key_code == WXK_RETURN or $key_code == WXK_SPACE;
-	if ( $key_code == WXK_TAB ) {
-		$event->ShiftDown
-		? Wx::Window::SetFocus($win->{close_button})
-		: Wx::Window::SetFocus($win->{range_group});
-	}
-	elsif ($key_code ==  WXK_ESCAPE) {$win->Close }
-	elsif ($key_code == 316) {Wx::Window::SetFocus( $win->{first_button} )}
-	elsif ($key_code == 317) {Wx::Window::SetFocus( $win->{fast_back_button} )}
-	elsif ($key_code == 318) {Wx::Window::SetFocus( $win->{close_button} )}
-	elsif ($key_code == 319) {Wx::Window::SetFocus( $win->{close_button} )}
-}
-
-sub replace_fore_keyfilter {
-	my ($win, $event) = (shift->GetParent, shift);
-	my $key_code = $event->GetKeyCode;
-
-	if ( $key_code == WXK_TAB ) {
-		$event->ShiftDown
-			? Wx::Window::SetFocus($win->{close_button})
-			: Wx::Window::SetFocus($win->{range_group});
-	}
-	elsif ( $key_code ==  WXK_RETURN ) {Kephra::Edit::Search::replace_fore()}
-	elsif ( $key_code ==  WXK_ESCAPE ) {$win->Close}
-	elsif ( $key_code ==  WXK_SPACE )  {Kephra::Edit::Search::replace_fore()}
-	elsif ( $key_code == 316 ) {Wx::Window::SetFocus( $win->{range_group} )}
-	elsif ( $key_code == 317 ) {Wx::Window::SetFocus( $win->{replace_button} )}
-	elsif ( $key_code == 318 ) {Wx::Window::SetFocus( $win->{replace_back} )}
-	elsif ( $key_code == 319 ) {Wx::Window::SetFocus( $win->{foreward_button} )}
-}
-
-sub replace_back_keyfilter {
-	my ($win, $event) = (shift->GetParent, shift);
-	my $key_code = $event->GetKeyCode;
-
-	if ( $key_code == WXK_TAB ) {
-		$event->ShiftDown
-		? Wx::Window::SetFocus($win->{close_button})
-		: Wx::Window::SetFocus($win->{range_group});
-	}
-	Kephra::Edit::Search::replace_back() if $key_code == WXK_RETURN or $key_code == WXK_SPACE;
-
-	if ( $key_code ==  WXK_ESCAPE ) {$win->Close}
-	if ( $key_code == 316 ) {Wx::Window::SetFocus( $win->{replace_fore} )}
-	if ( $key_code == 317 ) {Wx::Window::SetFocus( $win->{replace_button} )}
-	if ( $key_code == 318 ) {Wx::Window::SetFocus( $win->{replace_button} )}
-	if ( $key_code == 319 ) {Wx::Window::SetFocus( $win->{backward_button} )}
-}
+1;
\ No newline at end of file
