@@ -1,5 +1,5 @@
 package Kephra::Document;
-$VERSION = '0.43';
+$VERSION = '0.44';
 
 =pod
  This module is in rewrite mode the purpose 
@@ -9,43 +9,56 @@ $VERSION = '0.43';
 =cut
 
 use strict;
-use Wx qw(
-	wxSTC_EOL_CR wxSTC_EOL_LF wxSTC_EOL_CRLF
-);
+use Wx qw( wxSTC_EOL_CR wxSTC_EOL_LF wxSTC_EOL_CRLF );
 
 # internal functions
 # doc number
-sub _get_count      { @{ $Kephra::document{open} } }
+sub _attributes { $Kephra::document{open} } 
+sub _temp_data  { $Kephra::temp{document}{open} }
+
+sub _get_count      { @{ _attributes() } }
 sub _get_previous_nr{ $Kephra::document{previous_nr} }
 sub _set_previous_nr{ $Kephra::document{previous_nr} = shift }
 sub _get_current_nr { $Kephra::document{current_nr} }
 sub _set_current_nr {
 	my $nr = shift || 0;
 	$Kephra::document{current_nr} = $nr;
-	$Kephra::document{current}    = $Kephra::document{open}[$nr];
-	$Kephra::temp{current_doc}    = $Kephra::temp{document}{open}[$nr];
+	$Kephra::document{current}    = _attributes()->[$nr];
+	$Kephra::temp{current_doc}    = _temp_data()->[$nr];
+}
+sub current_nr {
+	my $nr = shift;
+	if (defined $nr) {
+		_set_current_nr($nr)
+	} else {
+		_get_current_nr()
+	}
 }
 sub _get_last_nr      { $#{ $Kephra::document{open} } }
 sub _get_nr_from_path {
 	my $given_path = shift;
+	my $attr = _attributes();
 	my @answer = ();
 	for ( 0 .. _get_last_nr() ) {
-		push @answer, $_ if $Kephra::document{open}[$_]{file_path} eq $given_path;
+		push @answer, $_ if $attr->[$_]{file_path} eq $given_path;
 	}
 	$#answer == -1 ? return 0 : return \@answer;
 }
 
-sub _get_path_from_nr{
+sub _get_path_from_nr {
 	my $nr = shift;
-	$Kephra::document{open}[$nr]{file_path} if $nr <= _get_last_nr()
+	_attributes()->[$nr]{file_path} if $nr <= _get_last_nr()
 }
 
-sub _get_current_file_path { $Kephra::document{current}{file_path} }
+sub _get_current_file_path {
+	$Kephra::document{current}{file_path}
+		if exists $Kephra::document{current}{file_path};
+}
 
 sub _get_all_pathes {
 	my @pathes;
-	my $docs = $Kephra::document{open};
-	$pathes[$_] = $docs->[$_]{file_path} for 0 .. _get_last_nr();
+	my $attr = _attributes();
+	$pathes[$_] = $attr->[$_]{file_path} for 0 .. _get_last_nr();
 	return \@pathes;
 }
 
@@ -53,7 +66,7 @@ sub set_file_path {
 	my ( $file_path, $doc_nr ) = @_;
 	$doc_nr ||= 0;
 	$doc_nr = _get_current_nr() unless $doc_nr;
-	$Kephra::document{open}[$doc_nr]{file_path} = $file_path;
+	_attributes()->[$doc_nr]{file_path} = $file_path;
 	Kephra::Document::Internal::dissect_path( $file_path, $doc_nr );
 	Kephra::App::TabBar::refresh_label($doc_nr);
 	Kephra::App::Window::refresh_title();
@@ -98,7 +111,9 @@ sub get_attribute {
 	return unless $attr;
 	my $nr = shift;
 	$nr = _get_current_nr() unless defined $nr;
-	$Kephra::document{open}[ $nr ]{$attr};
+	my $docs = _attributes();
+	return unless ref $docs eq 'ARRAY';
+	$docs->[ $nr ]{$attr};
 }
 
 sub set_attribute {
@@ -107,9 +122,90 @@ sub set_attribute {
 	return unless $value;
 	my $nr = shift;
 	$nr = _get_current_nr() unless defined $nr;
-	$Kephra::document{open}[ $nr ]{$attr} = $value
+	_attributes()->[ $nr ]{$attr} = $value
 }
 
+sub get_tmp_value {
+	my $name = shift;
+	return unless $name;
+	my $nr = shift;
+	$nr = _get_current_nr() unless defined $nr;
+	my $tmp_data = $Kephra::temp{document}{open};
+	$tmp_data->[ $nr ]{$name} if ref $tmp_data->[ $nr ] eq 'HASH';
+}
+
+sub set_tmp_value {
+	my $name = shift;
+	my $value = shift;
+	return unless $value;
+	my $nr = shift;
+	$nr = _get_current_nr() unless defined $nr;
+	$Kephra::temp{document}{open}[ $nr ]{$name} = $value
+}
+
+
+#########################################
+
+sub move_left {
+	my $old_nr = current_nr();
+	my $new_nr = $old_nr - 1;
+	if ($new_nr > -1) { switch($old_nr, $new_nr) }
+	else { 
+		$new_nr = _get_last_nr();
+		my $attr = _attributes();
+		my $data = _temp_data();
+		my $doc_a = shift @$attr;
+		push @$attr, $doc_a;
+		my $doc_d = shift @$data;
+		push @$data, $doc_d;
+		_set_current_nr($new_nr);
+		Kephra::App::TabBar::rot_tab_content('right');
+		Kephra::App::TabBar::set_current_page($new_nr);
+		Kephra::App::EditPanel::gets_focus();
+		Kephra::API::EventTable::trigger('document.list');
+	}
+}
+
+sub move_right {
+	my $old_nr = current_nr(); 
+	my $new_nr = $old_nr + 1;
+	if ( $new_nr <= _get_last_nr() ) { switch($old_nr, $new_nr) }
+	else {
+		$new_nr = 0;
+		my $attr = _attributes();
+		my $data = _temp_data();
+		my $doc_a = pop @$attr;
+		unshift @$attr, $doc_a;
+		my $doc_d = pop @$data;
+		unshift @$data, $doc_d;
+		_set_current_nr($new_nr);
+		Kephra::App::TabBar::rot_tab_content('left');
+		Kephra::App::TabBar::set_current_page($new_nr);
+		Kephra::App::EditPanel::gets_focus();
+		Kephra::API::EventTable::trigger('document.list');
+	}
+}
+
+sub switch {
+	my ($old_nr, $new_nr) = @_;
+	return unless defined $new_nr;
+	my $cur_nr = current_nr(); 
+	my $attr = _attributes();
+	my $data = _temp_data();
+	($attr->[$old_nr], $attr->[$new_nr]) = ($attr->[$new_nr], $attr->[$old_nr]);
+	($data->[$old_nr], $data->[$new_nr]) = ($data->[$new_nr], $data->[$old_nr]);
+	Kephra::App::TabBar::switch_tab_content($old_nr, $new_nr);
+	if ($cur_nr == $old_nr) {
+		_set_current_nr($new_nr);
+		Kephra::App::TabBar::set_current_page($new_nr);
+	} 
+	elsif ($cur_nr == $new_nr) {
+		_set_current_nr($old_nr);
+		Kephra::App::TabBar::set_current_page($old_nr);
+	}
+	Kephra::App::EditPanel::gets_focus();
+	Kephra::API::EventTable::trigger('document.list');
+}
 #########################################
 # getter/setter for Document properties
 #########################################
@@ -119,7 +215,7 @@ sub set_codepage {
 	# my $app_win = shift;
 	#$ep->SetCodePage(65001); wxSTC_CP_UTF8 Wx::wxUNICODE()
 	#Kephra::Dialog::msg_box(undef, Wx::wxUNICODE(), '');
-#use Wx::STC qw(wxSTC_CP_UTF8);
+	#use Wx::STC qw(wxSTC_CP_UTF8);
 }
 
 #
@@ -142,7 +238,7 @@ sub get_tab_mode { $Kephra::document{current}{tab_use} }
 sub set_tab_mode {
 	my $mode = shift || 0;
 	$Kephra::document{current}{tab_use} = $mode;
-	Kephra::App::EditPanel::_get()->SetUseTabs($mode);
+	Kephra::App::EditPanel::_ref()->SetUseTabs($mode);
 	Kephra::App::StatusBar::tab_info();
 }
 sub set_tabs_hard  { set_tab_mode(1) }
@@ -172,18 +268,18 @@ sub _edit{
 #
 sub get_EOL_mode { $Kephra::document{current}{EOL} }
 sub set_EOL_mode {
-	my $ep = Kephra::App::EditPanel::_get();
+	my $ep = Kephra::App::EditPanel::_ref();
 	my $mode      = shift;
 	$mode = $Kephra::config{file}{defaultsettings}{EOL_new} if ( !$mode );
 	my $eoll = \$Kephra::temp{current_doc}{EOL_length};
 	$$eoll = 1;
 	$mode = detect_EOL_mode() if $mode eq 'auto';
-	if    ( $mode eq 'lf' or $mode eq 'lin' ) { $ep->SetEOLMode(wxSTC_EOL_LF) } 
-	elsif ( $mode eq 'cr' or $mode eq 'mac' ) { $ep->SetEOLMode(wxSTC_EOL_CR) }
-	elsif ( $mode eq 'cr+lf'or $mode eq 'win'){ $ep->SetEOLMode(wxSTC_EOL_CRLF);
+	if    ( $mode eq 'lf'   or $mode eq 'lin') {$ep->SetEOLMode(wxSTC_EOL_LF) } 
+	elsif ( $mode eq 'cr'   or $mode eq 'mac') {$ep->SetEOLMode(wxSTC_EOL_CR) }
+	elsif ( $mode eq 'cr+lf'or $mode eq 'win') {$ep->SetEOLMode(wxSTC_EOL_CRLF);
 		$$eoll = 2;
 	}
-	$Kephra::document{current}{EOL} = $mode;
+	set_attribute('EOL', $mode);
 	Kephra::App::StatusBar::EOL_info($mode);
 }
 
@@ -193,7 +289,7 @@ sub set_EOL_mode_crlf { set_EOL_mode('cr+lf') }
 sub set_EOL_mode_auto { set_EOL_mode('auto' ) }
 
 sub convert_EOL {
-	my $ep = Kephra::App::EditPanel::_get();
+	my $ep = Kephra::App::EditPanel::_ref();
 	my $doc_nr    = &_get_current_nr;
 	my $mode      = shift;
 	$mode = $Kephra::config{file}{defaultsettings}{EOL_new} if ( !$mode );
@@ -210,7 +306,7 @@ sub convert_EOL_2_cr   { convert_EOL('cr') }
 sub convert_EOL_2_crlf { convert_EOL('cr+lf') }
 
 sub detect_EOL_mode {
-	my $ep = Kephra::App::EditPanel::_get();
+	my $ep = Kephra::App::EditPanel::_ref();
 	my $end_pos   = $ep->PositionFromLine(1);
 	my $begin_pos = $end_pos - 3;
 	$begin_pos = 0 if $begin_pos < 0;
@@ -282,7 +378,7 @@ sub set_bracelight_off {
 sub get_readonly { $Kephra::document{current}{readonly} }
 sub set_readonly {
 	my $status     = shift;
-	my $ep = Kephra::App::EditPanel::_get();
+	my $ep = Kephra::App::EditPanel::_ref();
 	my $file_name  = _get_current_file_path();
 	my $old_state  = $ep->GetReadOnly;
 
