@@ -1,5 +1,5 @@
 package Kephra::Document::Internal;
-$VERSION = '0.09';
+$VERSION = '0.10';
 
 use strict;
 use Wx qw(wxYES wxNO);
@@ -7,14 +7,17 @@ use Wx qw(wxYES wxNO);
 
 # make document empty and reset all document properties to default
 sub reset {
-	my $edit_panel = Kephra::App::EditPanel::_get();
+	my $doc_nr = shift;
+	$doc_nr = Kephra::Document::_get_current_nr() if not defined $doc_nr;
+	my $edit_panel = Kephra::App::EditPanel::_ref();
 	Kephra::Document::set_readonly(0);
 	$edit_panel->ClearAll;
 	$edit_panel->EmptyUndoBuffer;
 	$edit_panel->SetSavePoint;
-	Kephra::Document::set_file_path('');
-	reset_properties();
-	eval_properties();
+	reset_tmp_data($doc_nr);
+	reset_properties($doc_nr);
+	eval_properties($doc_nr);
+	Kephra::App::StatusBar::update_all();
 }
 
 # restore once opened file from his settings
@@ -44,6 +47,7 @@ sub restore {
 # add newly opened file
 sub add {
 	my $file_name = shift;
+	my $old_nr = Kephra::Document::_get_current_nr();
 	if ( defined $file_name and -e $file_name ) {
 
 		# open only text files and empty files
@@ -51,9 +55,10 @@ sub add {
 			and $Kephra::config{file}{open}{only_text} == 1 );
 
 		# check if file is already open and goto this already opened
-		if ( $Kephra::config{file}{open}{each_once} == 1 ){
+		if ( $Kephra::config{file}{open}{each_once} == 1){
 			for ( 0 .. Kephra::Document::_get_last_nr() ) {
-				if ( $Kephra::document{open}[$_]{file_path} eq $file_name ){
+				my $path = Kephra::Document::_get_path_from_nr($_);
+				if ($path and $path eq $file_name ){
 					Kephra::Document::Change::to_number($_);
 					return;
 				}
@@ -61,11 +66,14 @@ sub add {
 		}
 		save_properties();
 		my $doc_nr = new_if_allowed('add');
+		#return if $old_nr == $doc_nr; why?
 		$file_name = File::Spec->canonpath( $file_name );
+		Kephra::Document::_set_previous_nr($old_nr);
+		reset_tmp_data($doc_nr);
 		load_in_current_buffer($file_name);
+		reset_properties($doc_nr, $file_name);
 		Kephra::Document::_set_current_nr($doc_nr);
-		reset_properties();
-		eval_properties();
+		eval_properties($doc_nr);
 		Kephra::App::Window::refresh_title();
 		Kephra::App::EditPanel::Margin::autosize_line_number();
 		Kephra::API::EventTable::trigger('document.list');
@@ -76,7 +84,7 @@ sub add {
 # create a new document if settings allow it
 sub new_if_allowed {
 	my $mode = shift;	# new(empty), add(open) restore(open session)
-	my $ep  = Kephra::App::EditPanel::_get();
+	my $ep  = Kephra::App::EditPanel::_ref();
 	my $file_name = Kephra::Document::_get_current_file_path();
 	my $old_doc_nr= Kephra::Document::_get_current_nr();
 	my $doc_nr    = $Kephra::temp{document}{buffer};
@@ -104,7 +112,7 @@ sub new_if_allowed {
 	$Kephra::temp{document}{buffer}++;
 
 	change_pointer($doc_nr);
-	Kephra::App::TabBar::add_page();
+	Kephra::App::TabBar::add_tab();
 	Kephra::App::TabBar::set_current_page($doc_nr);
 	return $doc_nr;
 }
@@ -112,22 +120,24 @@ sub new_if_allowed {
 
 sub load_in_current_buffer {
 	my $file_name = shift || '';
-	my $edit_panel = Kephra::App::EditPanel::_get();
+	my $edit_panel = Kephra::App::EditPanel::_ref();
 	$edit_panel->ClearAll();
 	Kephra::File::IO::open_pipe($file_name);
 	$edit_panel->EmptyUndoBuffer;
 	$edit_panel->SetSavePoint;
 	Kephra::Document::set_file_path($file_name);
+	Kephra::File::_remember_save_moment($file_name);
 	$Kephra::temp{document}{loaded}++;
+	#if ($Kephra::config{editpanel}{scroll_width} eq 'auto'){}
 }
 
 
 sub check_b4_overwite {
 	my $filename = shift;
-	$filename = Kephra::Document::_get_current_file_path() unless $filename;
+	$filename = Kephra::Document::_get_current_file_path() unless defined $filename;
 	my $allow = $Kephra::config{file}{save}{overwrite};
 	if ( -e $filename ) {
-		my $frame = &Kephra::App::Window::_get();
+		my $frame = &Kephra::App::Window::_ref();
 		my $label = $Kephra::localisation{dialog};
 		if ( $allow eq 'ask' ) {
 			my $answer = Kephra::Dialog::get_confirm_2( $frame,
@@ -149,28 +159,38 @@ sub check_b4_overwite {
 
 # set the config default to the selected document
 sub reset_properties {
-	my $doc_nr = shift;
-	$doc_nr = $Kephra::document{current_nr} unless $doc_nr;
-	my $defaults  = $Kephra::config{file}{defaultsettings};
-	my $doc_attr  = $Kephra::document{open}[$doc_nr];
-	my $file_name = $doc_attr->{file_path};
+	my ($doc_nr, $file_name) = @_;
+	$doc_nr = Kephra::Document::_get_current_nr() unless defined $doc_nr;
+	my $def = $Kephra::config{file}{defaultsettings};
+	my $doc_attr = $Kephra::document{open}[$doc_nr] = {
+		'codepage' => $def->{codepage},
+		'edit_pos' => -1,
+		'file_path'=> $file_name,
+		'readonly' => $def->{readonly},
+		'syntaxmode'=>$def->{syntaxmode},
+		'tab_size' => $def->{tab_size},
+		'tab_use'  => $def->{tab_use},
+	};
 
-	$doc_attr->{syntaxmode} = $defaults->{syntaxmode} eq 'auto'
-		? Kephra::Document::SyntaxMode::_get_auto($doc_nr)
-		: $defaults->{syntaxmode};
+	$doc_attr->{syntaxmode} = Kephra::Document::SyntaxMode::_get_auto($doc_nr)
+		if defined $doc_attr->{syntaxmode} and $doc_attr->{syntaxmode} eq 'auto';
 
 	if ($file_name and ( -e $file_name )) 
-		 {$doc_attr->{EOL} = $defaults->{EOL_open}}
-	else {$doc_attr->{EOL} = $defaults->{EOL_new};
+		 {$doc_attr->{EOL} = $def->{EOL_open}}
+	else {$doc_attr->{EOL} = $def->{EOL_new};
 		Kephra::Document::set_EOL_mode( $doc_attr->{EOL} );
 	}
-	$doc_attr->{tab_use}  = $defaults->{tab_use};
-	$doc_attr->{tab_size} = $defaults->{tab_size};
-	$doc_attr->{codepage} = $defaults->{codepage};
-	$doc_attr->{readonly} = $defaults->{readonly};
-	$doc_attr->{cursor_pos} = 
-		$defaults->{cursor_pos} ? $defaults->{cursor_pos} : 0;
-	$doc_attr->{edit_pos} = -1;
+	$doc_attr->{cursor_pos} = $def->{cursor_pos} ? $def->{cursor_pos} : 0;
+}
+
+sub reset_tmp_data {
+	my $doc_nr = shift;
+	$doc_nr = Kephra::Document::_get_current_nr() unless defined $doc_nr;
+	my $pointer = $Kephra::temp{document}{open}[$doc_nr]{pointer};
+	$Kephra::temp{document}{open}[$doc_nr] = {
+		'pointer'    => $pointer,
+		'cursor_pos' => 0,
+	};
 }
 
 
@@ -179,7 +199,7 @@ sub eval_properties {
 	$doc_nr = Kephra::Document::_get_current_nr() if ( !$doc_nr );
 	my $doc_attr = \%{$Kephra::document{open}[$doc_nr]};
 	my $doc_data = \%{$Kephra::temp{document}{open}[$doc_nr]};
-	my $ep = Kephra::App::EditPanel::_get();
+	my $ep = Kephra::App::EditPanel::_ref();
 
 	$doc_attr->{syntaxmode} = "none" unless $doc_attr->{syntaxmode};
 	Kephra::Document::SyntaxMode::change_to( $doc_attr->{syntaxmode} );
@@ -193,29 +213,27 @@ sub eval_properties {
 		$doc_attr->{cursor_pos} < $doc_data->{selend}
 			? $ep->SetSelection( $doc_data->{selend},$doc_data->{selstart})
 			: $ep->SetSelection( $doc_data->{selstart},$doc_data->{selend});
-	} else { $ep->GotoPos( $doc_attr->{cursor_pos} ) }
+	} else { $ep->GotoPos( $doc_attr->{cursor_pos} ) 
+	}
 	if ($Kephra::config{file}{open}{in_current_dir}){
 		$Kephra::config{file}{current}{directory} = $doc_data->{directory}
 			if $doc_data->{directory};
 	} else { $Kephra::config{file}{current}{directory} = '' }
 	Kephra::Edit::_let_caret_visible();
-	#Kephra::App::StatusBar::refresh();
+	Kephra::App::StatusBar::refresh_cursor();
 	Kephra::App::EditPanel::set_word_chars();
 	Kephra::App::EditPanel::paint_bracelight()
 		if $Kephra::config{editpanel}{indicator}{bracelight}{visible};
 	Wx::Window::SetFocus($ep) unless $Kephra::temp{dialog}{control};
-	
-	# is that really necesary ?
-	Kephra::API::EventTable::trigger('document.savepoint','document.text.change');
 }
 
 
 sub save_properties {
 	my $doc_nr = shift;
-	$doc_nr = $Kephra::document{current_nr} unless $doc_nr;
+	$doc_nr = Kephra::Document::_get_current_nr() unless defined $doc_nr;
 	my $doc_attr = $Kephra::document{open}[$doc_nr];
 	my $doc_data = $Kephra::temp{document}{open}[$doc_nr];
-	my $ep = Kephra::App::EditPanel::_get();
+	my $ep = Kephra::App::EditPanel::_ref();
 
 	$doc_attr->{cursor_pos}= $ep->GetCurrentPos;
 	$doc_data->{selstart}  = $ep->GetSelectionStart;
@@ -228,7 +246,7 @@ sub change_pointer {
 	$newtab = 0 unless $newtab ;
 	my $oldtab  = Kephra::Document::_get_current_nr();
 	my $docsdata = $Kephra::temp{document}{open};
-	my $ep      = Kephra::App::EditPanel::_get();
+	my $ep      = Kephra::App::EditPanel::_ref();
 	$ep->AddRefDocument( $docsdata->[$oldtab]{pointer} );
 	$ep->SetDocPointer( $docsdata->[$newtab]{pointer} );
 	$ep->ReleaseDocument( $docsdata->[$newtab]{pointer} );
@@ -254,4 +272,4 @@ sub dissect_path {
 # depreciated
 sub set_path_slashes_to_OS_standart{ File::Spec->canonpath( shift ) }
 
-1;
+1;
\ No newline at end of file
